@@ -1,12 +1,15 @@
 import os
 import matplotlib
-from LivestockCV.core.fatal_error import fatal_error
+
 from LivestockCV.core.classes import Params
 from LivestockCV.core.classes import Outputs
 
+
+
 params = Params()
 outputs = Outputs()
 
+
 from LivestockCV.core.deprecation_warning import deprecation_warning
 from LivestockCV.core.print_image import print_image
 from LivestockCV.core.plot_image import plot_image
@@ -27,11 +30,17 @@ from LivestockCV.core.frame_count import frame_count
 from LivestockCV.core import js_to_image
 from LivestockCV.core import bbox_to_bytes
 from LivestockCV.core import take_photo
-# add new functions to end of lists
+from LivestockCV.core.show_image import show_image
+from LivestockCV.core.CalculateAngle import CalculateAngle
+from LivestockCV.core.Dimensions import Dimensions
+from LivestockCV.core.ContourMax import ContourMax
+from LivestockCV.core.fatal_error import fatal_error
 
-# Auto versioning
+
+
+# Versioning
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'rotate', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'js_to_image', 'bbox_to_bytes','take_photo']
+__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'rotate', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'js_to_image', 'bbox_to_bytes','take_photo', 'show_image', "CalculateAngle", 'Dimensions', 'ContourMax']
